@@ -10,7 +10,9 @@ from .astutils import ImportVisitor, walk
 
 
 def get_svn_version(path='.'):
-    """Uses `svnversion` to get just the latest revision at the given path."""
+    """Uses ``svnversion`` to get just the latest revision at the given
+    path.
+    """
 
     try:
         pipe = subprocess.Popen(['svnversion', path], stdout=subprocess.PIPE,
@@ -21,11 +23,11 @@ def get_svn_version(path='.'):
     if pipe.wait() != 0:
         return None
 
-    return pipe.stdout.read().decode('ascii').strip()
+    return pipe.stdout.read().decode('latin1').strip()
 
 
 def get_svn_info(path='.'):
-    """Uses `svn info` to get the full information about the working copy at
+    """Uses ``svn info`` to get the full information about the working copy at
     the given path.
     """
 
@@ -45,7 +47,7 @@ def get_svn_info(path='.'):
 
     lines = []
     for line in pipe.stdout.readlines():
-        line = line.decode('ascii').strip()
+        line = line.decode('latin1').strip()
         if not line:
             continue
         if line.startswith('Path:'):
